# Gestion des couleurs avec ngmaterial
![category](développement)
![tag](design)
![tag](angularjs)

Classique
---------

Avec ngmaterial il est possible de gérer les couleurs au niveau d'un thème

```javascript
// add theme
module.config(function($mdThemingProvider) {
        $mdThemingProvider.theme('default')
            .primaryPalette('green')
            .accentPalette('orange')
            .warnPalette('purple');
            });
```

Ce thème peut être modifié et crée de toutes pièces.

Par la suite ce thème est utilisé sur des objects standards: bouton, toolbar, ...

Ainsi un clic sur le bouton permet de voir toutes la gestion des nuances de couleur.


Utilisation avancée
-------------------

```warning
cette fonctionnalité n'existe que depuis la version 1.1.0
```

Il est aussi possible d'indiquer l'utilisation d'une couleur du thème
sur un object qui normalement n'est pas géré avec

```html
<div md-colors="{color: 'primary'}">primary</div>
<div md-colors="{color: 'accent'}">accent</div>
<div md-colors="{color: 'warn'}">warn</div>
<div md-colors="{color: 'primary-600'}">primary-600</div>
<div md-colors="{color: 'purple-primary-600'}">purple-primary-600</div>
```

Changement dynamique
--------------------

Il est possible de changer le theme global de façon dynamique.

Le principe est le suivant:

- on définit les thèmes possibles
- on active la possibilité de switcher
- on gère le theme par une variable **$scope.theme**
- changement de la variable lors d'un clic


```html
<html>
    ...
    <body md-theme="{{theme}}">
        <md-button ng-click="changeTheme()" class="md-fab to-bottom-right">
            <fa name="download fa-lg" aria-label="download"></fa>
        </md-button>
     <script>
        var app = angular.module('MyAppli', ['picardy.fontawesome','ngMaterial', 'md.data.table', 'ngSanitize', 'ngCsv','fixed.table.header']);
        // add theme
        app.config(function($mdThemingProvider) {
                $mdThemingProvider.theme('default')
                    .primaryPalette('green')
                    .accentPalette('orange')
                    .warnPalette('pink');
                    
                $mdThemingProvider.theme('indigo')
                  .primaryPalette('indigo')
                    .accentPalette('orange')
                    .warnPalette('pink');

                $mdThemingProvider.theme('lime')
                  .primaryPalette('lime')
                    .accentPalette('orange')
                    .warnPalette('pink');
                $mdThemingProvider.alwaysWatchTheme(true);
                    });
        app.controller('AppController', function($scope) {
        
            $scope.getInit = function() {
              $scope.theme = 'lime';
            };   
            
            $scope.changeTheme = function() {
                $scope.theme = $scope.theme === 'indigo' ? 'lime' : 'indigo'; 
            };
            
            // init data
            $scope.getInit();
        });
    </script>
</body>
```
